@@ -1,7 +1,7 @@
 --
 -- HTTP client for use with io-streams
 --
--- Copyright © 2012-2014 Operational Dynamics Consulting, Pty Ltd
+-- Copyright © 2012-2021 Athae Eredh Siniath and Others
 --
 -- The code in this file, and the program it is a part of, is
 -- made available to you by its authors as open source software:
@@ -116,6 +116,10 @@ module Network.Http.Client (
     ContentType,
     setContentType,
     setContentLength,
+    FieldName,
+    Boundary,
+    randomBoundary,
+    setContentMultipart,
     setExpectContinue,
     setTransferEncoding,
     setHeader,
@@ -126,9 +130,16 @@ module Network.Http.Client (
     getHostname,
     sendRequest,
     emptyBody,
+    simpleBody,
     fileBody,
     inputStreamBody,
     encodedFormBody,
+    multipartFormBody,
+    Part,
+    simplePart,
+    filePart,
+    inputStreamPart,
+    jsonBody,
 
     -- * Processing HTTP response
     receiveResponse,
@@ -140,8 +151,8 @@ module Network.Http.Client (
     getStatusMessage,
     getHeader,
     debugHandler,
-    concatHandler,
-    concatHandler',
+    simpleHandler,
+    simpleHandler',
     HttpClientError(..),
     jsonHandler,
 
@@ -177,8 +188,11 @@ module Network.Http.Client (
     Headers,
     getHeaders,
     getHeadersFull,
+    packBoundary,
 
     -- * Deprecated
+    concatHandler,
+    concatHandler',
     getRequestHeaders
 ) where
 
